Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AboutMessageCommand ¶
func AboutMessageCommand(s *discordgo.Session, m *discordgo.MessageCreate)
AboutMessageCommand takes a created message and returns an About embed message
func AboutSlashCommand ¶
func AboutSlashCommand(s *discordgo.Session, i *discordgo.InteractionCreate)
AboutSlashCommand returns an About embed message for a slash command
func OnGuildChannelCreateHandler ¶
func OnGuildChannelCreateHandler(b *Bot) func(*discordgo.Session, *discordgo.ChannelCreate)
OnGuildChannelCreateHandler is another specific use-case handler function that invalidates the bot's channel ID cache if the channel in the cache is deleted
Types ¶
type Bot ¶
type Bot struct {
Start time.Time
MessageCommands []*chat.MessageCommand
SlashCommands []*chat.SlashCommand
*discordgo.Session
// contains filtered or unexported fields
}
Bot encompasses a DiscordGo Bot
func (*Bot) RegisterSlashCommands ¶
Click to show internal directories.
Click to hide internal directories.